# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class HasAlphaChannelMatch(UniversalBaseModel):
    """
    The result's alpha channel presence is a match for the search query
    """

    has_alpha_channel: bool = pydantic.Field()
    """
    Whether the result has an alpha channel
    """

    type: typing.Literal["has_alpha_channel_match"] = "has_alpha_channel_match"

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
