# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class NameMatch(UniversalBaseModel):
    """
    The result's name is a match for the search query
    """

    name: str = pydantic.Field()
    """
    The name of the result
    """

    terms: typing.List[str] = pydantic.Field()
    """
    The terms in the search query that matched the result's name
    """

    type: typing.Literal["name_match"] = "name_match"

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
