# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class KeywordsMatch(UniversalBaseModel):
    """
    The result's keywords are a match for the search query
    """

    keywords: typing.List[str] = pydantic.Field()
    """
    The keywords of the result that are relevant to the search
    """

    type: typing.Literal["keywords_match"] = "keywords_match"

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
