# This file was auto-generated by Fern from our API Definition.

import typing

from .assignee_match import AssigneeMatch
from .audio_sample_rate_match import AudioSampleRateMatch
from .bit_depth_match import BitDepthMatch
from .bit_rate_match import BitRateMatch
from .channels_match import ChannelsMatch
from .codec_match import CodecMatch
from .color_space_match import ColorSpaceMatch
from .comment_count_match import CommentCountMatch
from .comment_match import CommentMatch
from .creator_match import CreatorMatch
from .deleted_at_match import DeletedAtMatch
from .duration_match import DurationMatch
from .dynamic_range_match import DynamicRangeMatch
from .file_type_match import FileTypeMatch
from .filesize_match import FilesizeMatch
from .format_match import FormatMatch
from .frame_rate_match import FrameRateMatch
from .has_alpha_channel_match import HasAlphaChannelMatch
from .inserted_at_match import InsertedAtMatch
from .keywords_match import KeywordsMatch
from .name_match import NameMatch
from .notes_match import NotesMatch
from .page_count_match import PageCountMatch
from .project_match import ProjectMatch
from .rating_match import RatingMatch
from .resolution_height_match import ResolutionHeightMatch
from .resolution_width_match import ResolutionWidthMatch
from .source_filename_match import SourceFilenameMatch
from .status_match import StatusMatch
from .transcription_match import TranscriptionMatch
from .updated_at_match import UpdatedAtMatch
from .uploaded_at_match import UploadedAtMatch
from .visual_match import VisualMatch

SearchMatch = typing.Union[
    NameMatch,
    SourceFilenameMatch,
    ProjectMatch,
    CreatorMatch,
    AssigneeMatch,
    FormatMatch,
    KeywordsMatch,
    StatusMatch,
    VisualMatch,
    TranscriptionMatch,
    CommentMatch,
    RatingMatch,
    CommentCountMatch,
    PageCountMatch,
    DurationMatch,
    FilesizeMatch,
    AudioSampleRateMatch,
    NotesMatch,
    UploadedAtMatch,
    UpdatedAtMatch,
    DeletedAtMatch,
    InsertedAtMatch,
    FileTypeMatch,
    BitDepthMatch,
    BitRateMatch,
    CodecMatch,
    ChannelsMatch,
    FrameRateMatch,
    HasAlphaChannelMatch,
    ColorSpaceMatch,
    ResolutionWidthMatch,
    ResolutionHeightMatch,
    DynamicRangeMatch,
]
