# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class ScrubSheetMediaLinkMetadata(UniversalBaseModel):
    """
    Metadata for the scrub sheet.<br>Metadata is only available for video assets.
    """

    frames: typing.Optional[int] = pydantic.Field(default=None)
    """
    Number of frames represented in the scrub sheet.
    """

    padding: typing.Optional[int] = pydantic.Field(default=None)
    """
    Padding in pixels between thumbnails.
    """

    thumb_height: typing.Optional[int] = pydantic.Field(default=None)
    """
    Thumbnail height in pixels.
    """

    thumb_width: typing.Optional[int] = pydantic.Field(default=None)
    """
    Thumbnail width in pixels.
    """

    tile_x: typing.Optional[int] = pydantic.Field(default=None)
    """
    Horizontal tile index (zero-based).
    """

    tile_y: typing.Optional[int] = pydantic.Field(default=None)
    """
    Vertical tile index (zero-based).
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
