# This file was auto-generated by Fern from our API Definition.

import typing

from .asset_search_result import AssetSearchResult
from .project_search_result import ProjectSearchResult

SearchResponseDataItem = typing.Union[AssetSearchResult, ProjectSearchResult]
