# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from .rendition_media_link import RenditionMediaLink
from .scrub_sheet_media_link_metadata import ScrubSheetMediaLinkMetadata


class ScrubSheetMediaLink(RenditionMediaLink):
    metadata: typing.Optional[ScrubSheetMediaLinkMetadata] = pydantic.Field(default=None)
    """
    Metadata for the scrub sheet.<br>Metadata is only available for video assets.
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
