# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class TranscriptionMatchMatchesItem(UniversalBaseModel):
    """
    A transcription segment that is a match for the search query
    """

    id: str = pydantic.Field()
    """
    Transcription segment ID
    """

    snippets: typing.List[str] = pydantic.Field()
    """
    The small portion of the transcription that is a match for the search query
    """

    terms: typing.List[str] = pydantic.Field()
    """
    The terms in the search query that are a match for the result's transcription
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
