# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .update_user_roles_response_data import UpdateUserRolesResponseData


class UpdateUserRolesResponse(UniversalBaseModel):
    data: UpdateUserRolesResponseData

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
