# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class FrameRateMatch(UniversalBaseModel):
    """
    The result's frame rate is a match for the search query
    """

    frame_rate: float = pydantic.Field()
    """
    The frame rate of the result in fps
    """

    type: typing.Literal["frame_rate_match"] = "frame_rate_match"

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
