# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .account_user_role import AccountUserRole
from .links import Links


class AccountUserRolesResponse(UniversalBaseModel):
    """
    Frame.io Account user role details
    """

    data: typing.List[AccountUserRole] = pydantic.Field()
    """
    Account User Roles
    """

    links: Links
    total_count: typing.Optional[int] = pydantic.Field(default=None)
    """
    Total count
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
