# This file was auto-generated by Fern from our API Definition.

import typing

SyncGroupWithIncludesSyncStatus = typing.Union[
    typing.Literal["not_started", "in_progress", "completed", "error"], typing.Any
]
