# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .user_single_definition_params_field_configuration import UserSingleDefinitionParamsFieldConfiguration


class UserSingleDefinitionParams(UniversalBaseModel):
    field_configuration: UserSingleDefinitionParamsFieldConfiguration
    field_type: typing.Literal["user_single"] = "user_single"
    name: str = pydantic.Field()
    """
    Field definition name
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
