# This file was auto-generated by Fern from our API Definition.

import typing

from .file import File
from .folder import Folder
from .version_stack import VersionStack

Asset = typing.Union[File, Folder, VersionStack]
