# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .unprocessable_content_errors_item import UnprocessableContentErrorsItem


class UnprocessableContent(UniversalBaseModel):
    errors: typing.List[UnprocessableContentErrorsItem]

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
