# This file was auto-generated by Fern from our API Definition.

import typing

FieldValueCommonFieldType = typing.Union[
    typing.Literal[
        "text",
        "long_text",
        "select",
        "select_multi",
        "rating",
        "number",
        "toggle",
        "users",
        "date",
        "user_multi",
        "user_single",
    ],
    typing.Any,
]
