# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class CreatorMatch(UniversalBaseModel):
    """
    The result's creator is a match for the search query
    """

    creator_id: str = pydantic.Field()
    """
    The ID of the user who created the result
    """

    type: typing.Literal["creator_match"] = "creator_match"

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
