# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from .group_common_with_includes import GroupCommonWithIncludes
from .sync_group_with_includes_sync_status import SyncGroupWithIncludesSyncStatus


class SyncGroupWithIncludes(GroupCommonWithIncludes):
    sync_status: SyncGroupWithIncludesSyncStatus = pydantic.Field()
    """
    Imported group sync status
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
