# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class Anchor(UniversalBaseModel):
    x: float = pydantic.Field()
    """
    Horizontal comment anchor location.
    """

    y: float = pydantic.Field()
    """
    Vertical comment anchor location.
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
