# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .transcription_match_matches_item import TranscriptionMatchMatchesItem


class TranscriptionMatch(UniversalBaseModel):
    """
    The result's transcription is a match for the search query
    """

    matches: typing.List[TranscriptionMatchMatchesItem] = pydantic.Field()
    """
    The transcriptions that match
    """

    type: typing.Literal["transcription_match"] = "transcription_match"

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
