# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .links import Links
from .search_response_data_item import SearchResponseDataItem


class SearchResponse(UniversalBaseModel):
    """
    Response containing search results
    """

    data: typing.List[SearchResponseDataItem] = pydantic.Field()
    """
    List of search results
    """

    links: Links
    total_count: typing.Optional[int] = pydantic.Field(default=None)
    """
    Total number of matching results
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
