# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class TextReviewAnnotationBounds(UniversalBaseModel):
    height: float = pydantic.Field()
    """
    Height of the rectangle
    """

    width: float = pydantic.Field()
    """
    Width of the rectangle
    """

    x: float = pydantic.Field()
    """
    Left corner position.
    """

    y: float = pydantic.Field()
    """
    Bottom corner position.
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
