# This file was auto-generated by Fern from our API Definition.

import typing

AssetSearchResultType = typing.Union[typing.Literal["file_result", "folder_result", "version_stack_result"], typing.Any]
