# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .project_match_project import ProjectMatchProject


class ProjectMatch(UniversalBaseModel):
    """
    The asset's project name is a match for the search query
    """

    project: ProjectMatchProject = pydantic.Field()
    """
    Project information for a project match
    """

    terms: typing.List[str] = pydantic.Field()
    """
    The terms in the search query that matched the project name
    """

    type: typing.Literal["project_match"] = "project_match"

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
