# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .visual_match_clips_item import VisualMatchClipsItem


class VisualMatch(UniversalBaseModel):
    """
    The result's content vector embedding is a match for the search query
    """

    clips: typing.List[VisualMatchClipsItem] = pydantic.Field()
    """
    The list of subclips matching the query
    """

    type: typing.Literal["visual_match"] = "visual_match"

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
