# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .select_definition_params_field_configuration_options_item import (
    SelectDefinitionParamsFieldConfigurationOptionsItem,
)


class SelectDefinitionParamsFieldConfiguration(UniversalBaseModel):
    enable_add_new: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Allow or disallow adding in new option(s) from the grid/list view
    """

    options: typing.List[SelectDefinitionParamsFieldConfigurationOptionsItem]

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
