# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import UniversalBaseModel
from .version_stack_reorder_params_data_move_to import VersionStackReorderParamsDataMoveTo


class VersionStackReorderParamsData(UniversalBaseModel):
    move_above_file_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    UUID of the file to move the target file above
    """

    move_below_file_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    UUID of the file to move the target file below
    """

    move_to: typing.Optional[VersionStackReorderParamsDataMoveTo] = pydantic.Field(default=None)
    """
    Move the target file to the top or bottom of the version stack
    """

    target_file_id: str = pydantic.Field()
    """
    UUID of the file to move
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
