# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class VisualMatchClipsItem(UniversalBaseModel):
    """
    A subclip within a video that is a match for the search query
    """

    best_frame_time: int = pydantic.Field()
    """
    Best matching frame time in milliseconds
    """

    end_time: int = pydantic.Field()
    """
    End time in milliseconds
    """

    index: int = pydantic.Field()
    """
    Chronological index of this clip
    """

    relevancy_index: int = pydantic.Field()
    """
    Index ordered by relevancy score
    """

    start_time: int = pydantic.Field()
    """
    Start time in milliseconds
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
