# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class Mention(UniversalBaseModel):
    end_index: int = pydantic.Field()
    """
    End index of mention text
    """

    start_index: int = pydantic.Field()
    """
    Start index of mention text
    """

    text: str = pydantic.Field()
    """
    Mention text
    """

    user_id: str = pydantic.Field()
    """
    Mentioned user ID
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
