# This file was auto-generated by Fern from our API Definition.

import typing

CommentSort = typing.Union[
    typing.Literal[
        "owner_asc", "owner_desc", "completed_at_asc", "completed_at_desc", "created_at_asc", "created_at_desc"
    ],
    typing.Any,
]
