# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .field_value_common_field_type import FieldValueCommonFieldType


class FieldValueCommon(UniversalBaseModel):
    """
    Metadata field value
    """

    field_definition_id: str = pydantic.Field()
    """
    Field definition ID
    """

    field_definition_name: str = pydantic.Field()
    """
    Field definition name
    """

    field_type: FieldValueCommonFieldType = pydantic.Field()
    """
    Field type
    """

    mutable: bool = pydantic.Field()
    """
    Metadata mutability. System field values cannot be updated.
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
