# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .user import User


class ShareReviewersResponse(UniversalBaseModel):
    """
    Share reviewers
    """

    data: typing.List[User] = pydantic.Field()
    """
    Share reviewer details
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
