# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class UploadedAtMatch(UniversalBaseModel):
    """
    The result's uploaded at timestamp is a match for the search query
    """

    type: typing.Literal["uploaded_at_match"] = "uploaded_at_match"
    uploaded_at: dt.datetime = pydantic.Field()
    """
    The uploaded at timestamp of the result
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
