# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.update_date_definition_params import UpdateDateDefinitionParams
from ...types.update_long_text_definition_params import UpdateLongTextDefinitionParams
from ...types.update_number_definition_params import UpdateNumberDefinitionParams
from ...types.update_rating_definition_params import UpdateRatingDefinitionParams
from ...types.update_select_definition_params import UpdateSelectDefinitionParams
from ...types.update_select_multi_definition_params import UpdateSelectMultiDefinitionParams
from ...types.update_text_definition_params import UpdateTextDefinitionParams
from ...types.update_toggle_definition_params import UpdateToggleDefinitionParams
from ...types.update_user_multi_definition_params import UpdateUserMultiDefinitionParams
from ...types.update_user_single_definition_params import UpdateUserSingleDefinitionParams

UpdateFieldDefinitionParamsData = typing.Union[
    UpdateDateDefinitionParams,
    UpdateLongTextDefinitionParams,
    UpdateNumberDefinitionParams,
    UpdateRatingDefinitionParams,
    UpdateSelectDefinitionParams,
    UpdateSelectMultiDefinitionParams,
    UpdateTextDefinitionParams,
    UpdateToggleDefinitionParams,
    UpdateUserMultiDefinitionParams,
    UpdateUserSingleDefinitionParams,
]
