# This file was auto-generated by Fern from our API Definition.

import typing

ProjectUserRolesIndexRequestSort = typing.Union[
    typing.Literal["role_asc", "role_desc", "name_asc", "name_desc", "email_asc", "email_desc"], typing.Any
]
