# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class AudioSampleRateMatch(UniversalBaseModel):
    """
    The result's audio sample rate is a match for the search query
    """

    audio_sample_rate: float = pydantic.Field()
    """
    The audio sample rate of the result in Hz
    """

    type: typing.Literal["audio_sample_rate_match"] = "audio_sample_rate_match"

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
