# This file was auto-generated by Fern from our API Definition.

import typing

from .file_with_includes import FileWithIncludes
from .folder_with_includes import FolderWithIncludes
from .version_stack_with_includes import VersionStackWithIncludes

AssetWithIncludes = typing.Union[FileWithIncludes, FolderWithIncludes, VersionStackWithIncludes]
