# This file was auto-generated by Fern from our API Definition.

import typing

FolderSort = typing.Union[
    typing.Literal["name_asc", "created_at_asc", "updated_at_asc", "name_desc", "created_at_desc", "updated_at_desc"],
    typing.Any,
]
