# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class ResolutionHeightMatch(UniversalBaseModel):
    """
    The result's resolution height is a match for the search query
    """

    resolution_height: float = pydantic.Field()
    """
    The resolution height of the result in pixels
    """

    type: typing.Literal["resolution_height_match"] = "resolution_height_match"

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
