# This file was auto-generated by Fern from our API Definition.

import typing

from .group_common_with_includes import GroupCommonWithIncludes
from .sync_group_with_includes import SyncGroupWithIncludes

GroupWithIncludes = typing.Union[SyncGroupWithIncludes, GroupCommonWithIncludes]
