# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from .action import Action
from .user import User


class ActionCreateResponseData(Action):
    creator: typing.Optional[User] = None
    secret: str = pydantic.Field()
    """
    Secret used to validate underlying webhook requests. Make sure to store your secret. You won’t be able to see it again!
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
