# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class BitRateMatch(UniversalBaseModel):
    """
    The result's bit rate is a match for the search query
    """

    bit_rate: float = pydantic.Field()
    """
    The bit rate of the result in bps
    """

    type: typing.Literal["bit_rate_match"] = "bit_rate_match"

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
