# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import UniversalBaseModel


class ActionUpdateParamsData(UniversalBaseModel):
    active: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Active Status
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Action description
    """

    event: typing.Optional[str] = pydantic.Field(default=None)
    """
    Event name sent to `url`
    """

    multi_asset: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Manages action trigger on multiple assets
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Action name
    """

    timeout: typing.Optional[int] = pydantic.Field(default=None)
    """
    Timeout for the action requests in seconds
    """

    url: typing.Optional[str] = pydantic.Field(default=None)
    """
    URL where `event` is sent
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
