# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .unprocessable_content_errors_item_source import UnprocessableContentErrorsItemSource


class UnprocessableContentErrorsItem(UniversalBaseModel):
    detail: str
    source: typing.Optional[UnprocessableContentErrorsItemSource] = None
    title: typing.Optional[str] = None

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
