# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel


class ProjectMatchInfo(UniversalBaseModel):
    """
    Project information for a project match
    """

    id: str = pydantic.Field()
    """
    The project ID
    """

    name: str = pydantic.Field()
    """
    The project name
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
