# This file was auto-generated by Fern from our API Definition.

import typing

SharesListReviewersRequestSort = typing.Union[typing.Literal["name_asc", "active", "name_desc", "inactive"], typing.Any]
