# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import UniversalBaseModel


class SearchParamsFilters(UniversalBaseModel):
    """
    Filters to control which types of results are returned
    """

    files_and_version_stacks: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Include files and version stacks in search results
    """

    folders: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Include folders in search results
    """

    projects: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Include projects in search results
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
