# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .project import Project
from .search_match import SearchMatch


class ProjectSearchResult(UniversalBaseModel):
    """
    A search result containing a project
    """

    matches: typing.List[SearchMatch] = pydantic.Field()
    """
    Matches explaining why this result was returned
    """

    result: Project
    type: typing.Literal["project_result"] = "project_result"

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
