# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import UniversalBaseModel
from .asset_common import AssetCommon
from .asset_search_result_type import AssetSearchResultType
from .search_match import SearchMatch


class AssetSearchResult(UniversalBaseModel):
    """
    A search result containing an asset (file, folder, or version stack)
    """

    matches: typing.List[SearchMatch] = pydantic.Field()
    """
    Matches explaining why this result was returned
    """

    result: AssetCommon
    type: AssetSearchResultType

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
